Learn R Programming

clhs (version 0.5-5)

cLHS_result: Conditioned Latin Hypercube Sampling result

Description

A S3 class describing a cLHS result.

Arguments

Value

An object of class cLHS_result contains the following slots:
index_samples
a vector giving the indices of the chosen samples.
sampled_data
the sampled data.frame.
obj
a vector giving the evolution of the objective function throughout the Meropolis-Hastings iterations.
cost
a vector giving the evolution of the cost function throughout the Meropolis-Hastings iterations, if available, otherwise NULL.

See Also

clhs